var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html } from 'lit';
import { customElement } from 'lit/decorators.js';
import { ComponentBase } from '../../../base/component-base/component.base';
import { dateFormat, getDayOfWeek, longMonthOption, yearDayOption, } from '../../../helpers/functions/date/date-methods';
import { CalendarBaseMethod } from './calendar-states/calendar-base';
import { CalendarDateRangeSelectState } from './calendar-states/daterange-select';
import { CalendarSingleSelectState } from './calendar-states/single-select';
export const tagName = 'cx-single-calendar';
// export const onPressed = 'pressed';
let SingleCalendar = class SingleCalendar extends ComponentBase {
    constructor() {
        super(...arguments);
        this.config = {
            calendar: undefined,
            selected: undefined,
            daterange: false,
        };
        this.day = [0, 1, 2, 3, 4, 5, 6];
    }
    connectedCallback() {
        super.connectedCallback();
        if (this.set)
            this.cacheConfig(this.set);
        if (this.config)
            this.exec();
        this.calendarMethod = new CalendarBaseMethod(this);
        this.dateRangeSelectState = new CalendarDateRangeSelectState(this);
        this.singleSelectState = new CalendarSingleSelectState(this);
    }
    render() {
        return html ` <style></style>

      <div class="calendar">
        <!-- title (month) -->
        <div class="title" @click="${this.setCalendarDisplay}">
          <div class="month">
            ${dateFormat(this.calendarMethod.dateConverted(), longMonthOption)}
          </div>
          <div class="year">
            ${dateFormat(this.calendarMethod.dateConverted(), yearDayOption)?.replace(/\W+/g, '')}
          </div>
        </div>
        <!-- day -->
        <div>
          ${this.day.map((day) => {
            return html `<div class="day">${getDayOfWeek(day, { weekday: 'short' })}</div>`;
        })}
        </div>
        <!-- week -->
        <div
          @click="${this.set.daterange
            ? (e) => this.dateRangeSelectState.selectRangeDate(e)
            : (e) => this.singleSelectState.selectSingleDate(e)}">
          ${this.set?.calendar?.calendar.map((week) => html `<div class="week">
                ${week.map((date) => {
            const { dateArray: dateValue, period, type, value, minmax } = date;
            return html `<div
                    data-date="${dateValue.join('-')}"
                    data-value="${value}"
                    @mouseover="${this.set.daterange
                ? () => this.dateRangeSelectState.setBetweenStartEndDate(date.date)
                : null}"
                    class="date ${type} ${minmax}"
                    data-period="${period}">
                    ${value}
                  </div> `;
        })}
              </div>`)}
        </div>
      </div>`;
    }
    setCalendarDisplay() {
        this.dispatchEvent(new CustomEvent('calendar-display', {
            bubbles: true,
            detail: {
                date: this.calendarMethod.dateConverted(),
            },
        }));
    }
    updated(changedProps) {
        // ⚠ FIXME: willUpdate will execute everytimes when change month
        this.updateSelected();
        super.update(changedProps);
    }
    // 📌this methods only call from calendar monitor **observer trigger
    updateSelected() {
        this.set.daterange
            ? this.dateRangeSelectState.updateRangeSelected()
            : this.singleSelectState.updateSingleSelected();
    }
};
// 0 | 304 | 608
SingleCalendar.styles = css `
    .calendar {
      width: 304px;
      background-color: var(--white);
      display: flex;
      flex-flow: column;
      align-items: center;
    }
    .date {
      width: var(--size-40);
      height: var(--size-40);
      color: var(--gray-700);
      font-size: var(--size-14);
      background-color: var(--white);
      display: inline-flex;
      justify-content: center;
      align-items: center;
      border-radius: var(--base-size-half);
      transition: background-color 0.2s ease, scale 0.075s ease;
      cursor: pointer;
    }

    .date:hover {
      background-color: var(--primary-100);
      /* scale: 1.22; */
    }

    .date:active {
      scale: 1;
    }
    .selected,
    .startdate,
    .enddate {
      background-color: var(--primary-500) !important;
      color: var(--white) !important;
      border-radius: var(--base-size-half) !important;
      position: relative;
      animation: selected 0.25s ease;
    }

    @keyframes selected {
      0% {
        scale: 1;
      }
      50% {
        scale: 1.2;
      }
      100% {
        scale: 1;
      }
    }

    .selected:hover {
      background-color: var(--primary-600);
      color: var(--white);
    }

    .day {
      width: var(--size-40);
      height: var(--size-40);
      font-size: var(--size-14);
      display: inline-flex;
      justify-content: center;
      align-items: center;
      background-color: var(--white);
    }

    .title {
      display: flex;
      justify-content: center;
      column-gap: var(--base-size-12);
      font-size: var(--size-16);
      position: relative;
      bottom: var(--size-6);
      font-family: var(--semiBold);
      cursor: pointer;
      transition: color 0.25s ease;
    }

    .title:hover {
      color: var(--primary-700) !important;
    }

    .week {
      display: flex;
    }

    .date[data-period='today'] {
      position: relative;
      z-index: 2;
      color: var(--primary-900);
      font-family: var(--extraBold);
    }

    .date[data-period='today']:hover {
      background-color: var(--primary-100);
    }

    .min,
    .max {
      pointer-events: none;
      color: var(--gray-300) !important;
    }

    .month,
    .year {
      display: inline-block;
    }

    .date[data-datebetween] {
      border-radius: var(--size-0);
    }

    .next-month,
    .previous-month {
      color: var(--gray-300) !important;
      pointer-events: none;
      background-color: var(--white) !important;
    }

    .current-month {
      color: var(--gray-700);
    }

    .startdate:not(.previous-month, .next-month)::before,
    .enddate:not(.previous-month, .next-month)::before {
      content: '';
      background-color: var(--primary-100);
      width: 20px;
      height: 40px;
      position: absolute;
      z-index: 0;
    }
    .startdate::before {
      right: 0;
    }
    .enddate::before {
      left: 0;
    }

    .enddate:not(.previous-month, .next-month)::after,
    .startdate:not(.previous-month, .next-month)::after {
      content: attr(data-value);
      background-color: var(--primary-500);
      position: absolute;
      width: 40px;
      height: 40px;
      z-index: 1;
      display: flex;
      justify-content: center;
      align-items: center;
      border-radius: var(--base-size-half);
    }
  `;
SingleCalendar = __decorate([
    customElement(tagName)
], SingleCalendar);
export { SingleCalendar };
//# sourceMappingURL=single-calendar.js.map