var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { html } from 'lit';
import { customElement, state } from 'lit/decorators.js';
import { ComponentBase } from '../../base/component-base/component.base';
import { createRef, ref } from 'lit/directives/ref.js';
import '../c-box/c-box';
import '../popover/popover';
import '../calendar/calendar';
import { convertDateToArrayNumber, dateFormat, } from '../../helpers/functions/date/date-methods';
import { delay } from '../../helpers/delay';
import { CxDatepickerName } from './types/datepicker.name';
import { UI } from './ui/datepicker.ui';
// export const onPressed = 'pressed';
let DatePicker = class DatePicker extends ComponentBase {
    constructor() {
        super(...arguments);
        this.config = {
            date: new Date(),
            min: undefined,
            max: undefined,
            initValue: true,
            multiSelect: false,
            dateRange: false,
            display: '1-calendar',
            inputStyle: 'long',
            valueStyle: {
                dateStyle: 'medium',
            },
            dateValue: undefined,
            rangeValue: undefined,
            focusout: 'close',
            mouseleave: 'none',
            disabled: undefined,
            error: undefined,
            rangeError: undefined,
            rangeDisabled: undefined,
        };
        this.styles = {
            heightInput: '44',
            widthInput: '310',
        };
        this.inputBoxWrapperRef = createRef();
        this.cxCalendarRef = createRef();
        this.popoverContentRef = createRef();
        this.datepickerState = 'closed';
    }
    connectedCallback() {
        super.connectedCallback();
        if (this.set)
            this.cacheConfig(this.set);
        if (this.config)
            this.exec();
        // 📌only use when component styles base on c-box *The Component does not have shadowRoot.
        if (this.var)
            this.cacheVariables(this.var);
        if (this.styles)
            this.setVar();
    }
    render() {
        return html `
      <style>
        cx-datepicker .disabled-bg {
          background: var(--gray-200);
          cursor: not-allowed;
        }

        cx-datepicker .error-border {
          border-color: #f3655c !important;
        }
      </style>
      <cx-popover
        @opened="${this.popoverOpened}"
        @closed="${this.popoverClosed}"
        .set="${{
            disabled: this.set.disabled,
            position: 'bottom-left',
            openby: 'click',
            mouseleave: this.set.mouseleave,
            focusout: this.set.focusout,
        }}">
        <c-box slot="host">
          <c-box ui="${this.setInputStyle()}" ${ref(this.inputBoxWrapperRef)}>
            ${this.renderDateInput()}
          </c-box>
        </c-box>
        <c-box slot="popover" ${ref(this.popoverContentRef)}>
          <c-box content p="0">
            ${this.datepickerState === 'opened'
            ? html `
                  <cx-calendar
                    ${ref(this.cxCalendarRef)}
                    @select-date="${this.selectDate}"
                    .set="${this.set}"></cx-calendar>
                `
            : undefined}
          </c-box>
        </c-box>
      </cx-popover>
    `;
    }
    setInputStyle() {
        return this.set.inputStyle === 'long' ? UI.inputLong : UI.inputShort;
    }
    createRenderRoot() {
        return this;
    }
    renderInputBox(text, type) {
        const { disabled, error, rangeDisabled, rangeError } = this.set;
        const inputState = !rangeDisabled && !rangeError
            ? `${disabled ? 'disabled-bg' : ''} ${error ? 'error-border' : ''}`
            : '';
        const endDateInputState = `${rangeDisabled?.endDate && type === 'enddate' ? 'disabled-bg' : ''} ${rangeError?.endDate && type === 'enddate' ? 'error-border' : ''}`;
        const startDateInputState = `${rangeDisabled?.startDate && type === 'startdate' ? 'disabled-bg' : ''} ${rangeError?.startDate && type === 'startdate' ? 'error-border' : ''}`;
        return html `
      <c-box
        @mouseenter="${() => this.checkDisabledDate(type)}"
        class="${inputState} ${endDateInputState} ${startDateInputState}"
        ui="${UI.inputDateBox}"
        icon-prefix="22 calendar-alt-line gray-600"
        input-date-type="${type}"
        input-box="default"
        w="${this.var.widthInput}!"
        h="${this.var.heightInput}!"
        >${text}</c-box
      >
    `;
    }
    checkDisabledDate(type) {
        const isEndDate = type === 'enddate';
        const isStartDate = type === 'startdate';
        const isEndDateDisabled = this.set.rangeDisabled?.endDate;
        const isStartDateDisabled = this.set.rangeDisabled?.startDate;
        if (isEndDate) {
            this.toggleFixBasedOnCondition(isEndDateDisabled);
        }
        else if (isStartDate) {
            this.toggleFixBasedOnCondition(isStartDateDisabled);
        }
    }
    toggleFixBasedOnCondition(condition) {
        this.set.disabled = condition;
        this.requestUpdate();
    }
    getSelectedDateRangeText() {
        const dateRangeValue = this.set.rangeValue;
        const startdate = this.set.initValue ? dateRangeValue?.startDate : undefined;
        const enddate = this.set.initValue ? dateRangeValue?.endDate : undefined;
        const startdateFormatted = dateFormat(startdate, this.set.valueStyle);
        const enddateFormatted = dateFormat(enddate, this.set.valueStyle);
        return { startdate: startdateFormatted, enddate: enddateFormatted };
    }
    renderDateInput() {
        if (this.set.dateRange) {
            const { startdate, enddate } = this.getSelectedDateRangeText();
            return this.getInputBoxForDateRange(startdate, enddate);
        }
        else {
            const date = this.set.initValue ? this.set.dateValue : undefined;
            const dateFormatted = dateFormat(date?.date, this.set.valueStyle);
            return this.getInputBoxForSingleDate(dateFormatted);
        }
    }
    popoverClosed(e) {
        this.datepickerState = e.detail.state;
        const firstInput = this.inputBoxWrapperRef.value.firstElementChild;
        if (this.set.dateRange) {
            const enddateInput = this.inputBoxWrapperRef.value.lastElementChild;
            this.setDefaultOnInputBox(firstInput);
            this.setDefaultOnInputBox(enddateInput);
            if (this.set.rangeValue?.startDate && !this.set.rangeValue.endDate) {
                this.set.rangeValue.endDate = this.endDateCache;
            }
        }
        else {
            this.setDefaultOnInputBox(firstInput);
        }
    }
    popoverOpened(e) {
        this.datepickerState = e.detail.state;
        const inputDateBoxRef = e.detail.event.target;
        if (!inputDateBoxRef.hasAttribute('input-box'))
            return;
        const inputDateType = inputDateBoxRef.getAttribute('input-date-type');
        if (inputDateType === 'enddate') {
            inputDateBoxRef.setAttribute('input-box', 'focus');
            if (this.set?.rangeValue?.endDate) {
                this.endDateCache = this.set.rangeValue.endDate;
            }
            requestAnimationFrame(() => {
                this.resetEndDateSelected();
            });
        }
        this.setFocusOnInputBox(inputDateBoxRef);
    }
    resetEndDateSelected() {
        if (!this.cxCalendarRef.value)
            return;
        this.cxCalendarRef.value?.calendarMonitorRef.value?.setAttribute('enddate-selected', '');
        this.cxCalendarRef.value?.calendarMonitorRef.value?.setAttribute('old-enddate', convertDateToArrayNumber(this.set.rangeValue?.endDate)?.join('-'));
        this.cxCalendarRef.value.dateNavigator = this.endDateCache;
    }
    async selectDate(e) {
        if (this.set.dateRange) {
            this.setSelectDateRangeFocus(e.detail);
        }
        this.setCustomEvent('select-date', { ...e.detail });
        await this.setClosePopover(e.detail);
    }
    setSelectDateRangeFocus(date) {
        const startdateInput = this.inputBoxWrapperRef.value.firstElementChild;
        const enddateInput = this.inputBoxWrapperRef.value.lastElementChild;
        if (!date.startDate) {
            this.setFocusOnInputBox(startdateInput);
        }
        else {
            this.setDefaultOnInputBox(startdateInput);
            this.setFocusOnInputBox(enddateInput);
        }
    }
    async setClosePopover(date) {
        if (this.set.dateRange) {
            if (!(date.startDate && date.endDate))
                return;
            // 📌 delay for animation selected enddate scale
            await delay(175);
            this.popoverContentRef.value?.popoverState?.closePopover(null);
        }
        else {
            if (!date.date)
                return;
            // 📌 delay for animation selected enddate scale
            await delay(175);
            this.popoverContentRef.value?.popoverState?.closePopover(null);
        }
    }
    getInputBoxForDateRange(startdateFormatted, enddateFormatted) {
        return html `
      ${this.renderInputBox(startdateFormatted || 'วันเริ่มต้น', 'startdate')}
      ${this.set.inputStyle === 'long' ? html `<c-box>-</c-box>` : undefined}
      ${this.renderInputBox(enddateFormatted || 'วันสิ้นสุด', 'enddate')}
    `;
    }
    getInputBoxForSingleDate(dateFormatted) {
        return html ` ${this.renderInputBox(dateFormatted || 'เลือกวันที่', 'singledate')} `;
    }
    setFocusOnInputBox(inputBox) {
        inputBox?.setAttribute('input-box', 'focus');
    }
    setDefaultOnInputBox(inputBox) {
        inputBox?.setAttribute('input-box', 'default');
    }
};
__decorate([
    state(),
    __metadata("design:type", String)
], DatePicker.prototype, "datepickerState", void 0);
DatePicker = __decorate([
    customElement(CxDatepickerName)
], DatePicker);
export { DatePicker };
//# sourceMappingURL=datepicker.js.map