var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html } from 'lit';
import { customElement } from 'lit/decorators.js';
import { createRef, ref } from 'lit/directives/ref.js';
import { ComponentBase } from '../../base/component-base/component.base';
import { GlobalDialogSingleton } from '../dialog/singleton/global-dialog.singleton';
import { ModalSingleton } from './singleton/modal.singleton';
import { DialogState } from './state/dialog.state';
import { PopoverState } from './state/popover-state/popover.state';
import { SnackbarState } from './state/snackbar.state';
import { CxModalName } from './types/modal.name';
// export const onPressed = 'pressed';
let Modal = class Modal extends ComponentBase {
    constructor() {
        super(...arguments);
        this.config = {
            disabledBackdrop: false,
        };
        this.dialogSlotRef = createRef();
        this.snackbarSlotRef = createRef();
        this.popoverSlotRef = createRef();
        // 📌need to use arrow function becoz this function is called from outside scope
        this.openDialog = async (slotName) => await this.dialogState.open({
            slotRef: this.dialogSlotRef,
            slotName,
        });
        this.closeDialog = () => {
            this.dialogState.close();
        };
        this.openSnackbar = (slot) => {
            this.snackbarState.open({
                slotName: slot,
                slotRef: this.snackbarSlotRef,
            });
        };
        this.openPopover = (popoverContent, hostRect, popoverSet, popoverRoot, triggerEvent) => {
            popoverContent.popoverState = new PopoverState().open(popoverContent, hostRect, popoverSet, popoverRoot, triggerEvent);
        };
    }
    connectedCallback() {
        super.connectedCallback();
        if (this.set)
            this.cacheConfig(this.set);
        if (this.config)
            this.exec();
        super.connectedCallback();
        this.createModalState();
        this.createSharedCXModalRef();
    }
    render() {
        return html `
      <!-- 📌menu is a popover that can display multiple popovers -->
      <!-- menu area -->
      <div class="menu area disabled"></div>

      <!-- 📌popover / tooltip area -->
      <div class="popover area disabled">
        <slot name="${PopoverState.POPOVER_SLOT_DISABLED}" ${ref(this.popoverSlotRef)}></slot>
      </div>

      <!-- 📌snackbar area -->
      <div data-snackbar-position="top-center" class="snackbar area disabled">
        <slot name="${SnackbarState.SNACKBAR_SLOT_DISABLED}" ${ref(this.snackbarSlotRef)}></slot>
      </div>

      <!-- 📌 dialog area -->
      <div @click="${this.dialogState.closeBackdrop}" class="dialog area disabled">
        <slot
          @click="${(e) => e.stopPropagation()}"
          ${ref(this.dialogSlotRef)}
          name="${DialogState.DIALOG_SLOT_DEFAULT}"></slot>
      </div>
      <slot></slot>
    `;
    }
    createModalState() {
        this.dialogState = new DialogState();
        this.snackbarState = new SnackbarState();
    }
    createSharedCXModalRef() {
        ModalSingleton.modalRef = this;
        requestAnimationFrame(() => {
            ModalSingleton.popoverSlotRef = this.popoverSlotRef.value;
            GlobalDialogSingleton.ref = this.querySelector('cx-dialog');
        });
    }
};
Modal.MODAL_DISABLED = 'disabled';
Modal.styles = css `
    :host {
      --opacity: 0;
      --background-color: var(--base-shadow-400);
    }
    .area {
      height: 100%;
      width: 100%;
      position: fixed;
    }

    .dialog {
      background-color: var(--background-color);
      opacity: var(--opacity);
      transition: opacity 0.25s;
      z-index: 2;
    }

    .dialog__enabled {
      display: flex;
      align-items: center;
      justify-content: center;
    }

    .disabled {
      display: none;
    }

    .snackbar {
      z-index: 1;
      pointer-events: none;
    }

    .snackbar__enabled {
      display: flex;
      padding: var(--base-size-24);
      box-sizing: border-box;
    }

    .snackbar[data-snackbar-position='top-left'] {
      justify-content: flex-start;
    }
    .snackbar[data-snackbar-position='top-center'] {
      justify-content: center;
    }
    .snackbar[data-snackbar-position='top-right'] {
      justify-content: flex-end;
    }

    .snackbar[data-snackbar-position='bottom-left'] {
      flex-direction: column-reverse;
      align-items: flex-start;
    }
    .snackbar[data-snackbar-position='bottom-center'] {
      flex-direction: column-reverse;
      align-items: center;
    }

    .snackbar[data-snackbar-position='bottom-right'] {
      flex-direction: column-reverse;
      align-items: flex-end;
    }

    .snackbar > slot {
      pointer-events: auto;
    }

    .popover {
      z-index: 3;
      pointer-events: none;
    }
    .popover > slot {
      pointer-events: auto;
    }
  `;
Modal = __decorate([
    customElement(CxModalName)
], Modal);
export { Modal };
//# sourceMappingURL=modal.js.map