import { SnackbarSingleton } from '../../snackbar/singleton/snackbar.singleton';
import { Modal } from '../modal';
export class SnackbarState {
    constructor() {
        this.SNACKBAR_ENABLED = 'snackbar__enabled';
        this.open = (detail) => {
            if (!this.snackbarSlot)
                this.snackbarSlot = detail.slotRef;
            this.startTransition();
            this.setSnackbarSlotName(detail.slotName);
            this.toggleSnackbarClasses();
        };
    }
    startTransition() {
        requestAnimationFrame(() => {
            SnackbarSingleton.ref.executeTransition('start');
        });
    }
    setSnackbarPosition(snackbarParent) {
        snackbarParent.dataset.snackbarPosition = SnackbarSingleton.ref.set.position;
    }
    setSnackbarSlotName(slot) {
        if (!this.snackbarSlot?.value?.parentElement)
            return;
        this.snackbarSlot.value.name = slot;
    }
    toggleSnackbarClasses() {
        if (!this.snackbarSlot?.value?.parentElement)
            return;
        this.clearSnackbarTimeout();
        const snackbarParent = this.snackbarSlot.value.parentElement;
        this.setSnackbarPosition(snackbarParent);
        this.enabledSnackbarClass(snackbarParent);
        this.transitionEndSnackbar();
        this.disabledSnackbarClass(snackbarParent);
    }
    enabledSnackbarClass(snackbarParent) {
        snackbarParent.classList.add(this.SNACKBAR_ENABLED);
        snackbarParent.classList.remove(Modal.MODAL_DISABLED);
    }
    disabledSnackbarClass(snackbarParent) {
        this.snackbarTimeStart = setTimeout(() => {
            if (!this.snackbarSlot?.value)
                return;
            this.snackbarSlot.value.name = SnackbarState.SNACKBAR_SLOT_DISABLED;
            snackbarParent.classList.add(Modal.MODAL_DISABLED);
            snackbarParent.classList.remove(this.SNACKBAR_ENABLED);
        }, SnackbarSingleton.ref.set.duration);
    }
    transitionEndSnackbar() {
        this.snackbarTimeEnd = setTimeout(() => {
            SnackbarSingleton.ref.executeTransition('end');
        }, SnackbarSingleton.ref.set.duration - 250);
    }
    clearSnackbarTimeout() {
        clearTimeout(this.snackbarTimeEnd);
        clearTimeout(this.snackbarTimeStart);
    }
}
SnackbarState.SNACKBAR_SLOT_DISABLED = 'snackbar-disabled';
//# sourceMappingURL=snackbar.state.js.map