var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html } from 'lit';
import { customElement } from 'lit/decorators.js';
import { ComponentBase } from '../../base/component-base/component.base';
import { ModalSingleton } from '../modal/singleton/modal.singleton';
import { createRef, ref } from 'lit/directives/ref.js';
import { REQUIRED_CBOX_CHILD_POPOVER_ERROR } from './errors/popover.errors';
import { CxPopoverName } from './types/popover.name';
let Popover = class Popover extends ComponentBase {
    constructor() {
        super(...arguments);
        this.config = {
            openby: 'click',
            position: 'bottom-center',
            mouseleave: 'none',
            focusout: 'close',
            arrowpoint: false,
            transform: 'origin',
            disabled: undefined,
        };
        this.hostSlotRef = createRef();
        this.popoverSlotRef = createRef();
        this.setOpenPopover = async (triggerEvent) => {
            if (this.set.disabled)
                return;
            const popoverContentElement = await this.getPopoverContentElement();
            if (!popoverContentElement)
                return;
            ModalSingleton.modalRef.openPopover(popoverContentElement, this.hostElement.getBoundingClientRect(), this.set, this.shadowRoot.host, triggerEvent);
        };
    }
    render() {
        return html `
      <slot name="host" ${ref(this.hostSlotRef)}></slot>
      <slot class="popover-disabled" name="popover" ${ref(this.popoverSlotRef)}></slot>
    `;
    }
    async connectedCallback() {
        super.connectedCallback();
        if (this.set)
            this.cacheConfig(this.set);
        if (this.config)
            this.exec();
        this.hostElement = await this.setHostElement();
        this.setHostEvent();
    }
    setHostElement() {
        return new Promise((resolve) => {
            requestAnimationFrame(() => {
                resolve(this.hostSlotRef.value?.assignedElements()[0]);
            });
        });
    }
    setHostEvent() {
        this.hostElement?.addEventListener(this.set.openby, this.setOpenPopover);
        this.hostElement?.setAttribute('inline-block', '');
    }
    async getPopoverContentElement() {
        return await this.getPopoverContent();
    }
    getPopoverContent() {
        return new Promise((resolve, reject) => {
            requestAnimationFrame(() => {
                const cBox = this.popoverSlotRef.value?.assignedElements()[0];
                if (cBox) {
                    cBox.tagName === 'C-BOX' ? resolve(cBox) : reject(REQUIRED_CBOX_CHILD_POPOVER_ERROR);
                }
                else {
                    resolve(null);
                    console.warn('You must close popover by close button');
                }
            });
        });
    }
};
Popover.styles = css `
    .popover-disabled {
      display: none;
    }
  `;
Popover = __decorate([
    customElement(CxPopoverName)
], Popover);
export { Popover };
//# sourceMappingURL=popover.js.map